@@ -242,7 +242,7 @@ impl AstVisitor for LuaWritter {
 
     fn assign_stat(&mut self, stat: &AssignStat) {
         for (n, suffix) in stat.left.iter().enumerate() {
-            ast_walker::walk_suffixedexpr(suffix, self);
+            ast_walker::walk_assinable(suffix, self);
             if n < stat.left.len() - 1 {
                 self.append_space(",");
             }
@@ -252,7 +252,7 @@ impl AstVisitor for LuaWritter {
     }
 
     fn call_stat(&mut self, stat: &CallStat) {
-        ast_walker::walk_suffixedexpr(&stat.call, self);
+        ast_walker::walk_assinable(&stat.call, self);
     }
 
     fn expr(&mut self, _stat: &Expr) -> bool {
@@ -422,12 +422,6 @@ impl AstVisitor for LuaWritter {
 
     fn end_suffixed_expr(&mut self) {}
 
-    fn begin_primary_expr(&mut self, _expr: &PrimaryExpr) -> bool {
-        false
-    }
-
-    fn end_primary_expr(&mut self) {}
-
     fn name(&mut self, name: &str) {
         self.append(name);
     }
@@ -504,8 +498,8 @@ use std::process::Command;
 fn exists_lua_bin() -> Option<String> {
     if let Ok(_) = Command::new("lua").output() {
         Some("lua".to_string())
-    } else if let Ok(_) = Command::new("lua53").output() {
-        Some("lua53".to_string())
+    } else if let Ok(_) = Command::new("lua5.3").output() {
+        Some("lua5.3".to_string())
     } else {
         None
     }
@@ -551,8 +545,8 @@ fn lua_to_lua() -> std::io::Result<()> {
 
         // execute lua sources from origin paths and temp paths, then compare their outputs
         assert_eq!(
-            execute_lua_tests(&bin, "./lua"),
-            execute_lua_tests(&bin, "./tmp")
+            execute_lua_tests(&bin, "lua"),
+            execute_lua_tests(&bin, "tmp")
         );
     }
 
